@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: ccsidcurl.c,v 1.6 2008-04-07 13:09:17 patrickm Exp $
+ * $Id: ccsidcurl.c,v 1.12 2008-10-17 13:17:41 patrickm Exp $
  *
  ***************************************************************************/
 
@@ -33,6 +33,7 @@
 #pragma enum(int)
 
 #include <curl/curl.h>
+#include <curl/mprintf.h>
 #include "urldata.h"
 #include "url.h"
 #include "getinfo.h"
@@ -727,7 +728,7 @@ curl_formadd_ccsid(struct curl_httppost * * httppost,
   /* Allocate the local curl_forms array. */
 
   lformlen = ALLOC_GRANULE;
-  lforms = (struct curl_forms *) malloc(lformlen * sizeof * lforms);
+  lforms = malloc(lformlen * sizeof *lforms);
 
   if (!lforms)
     return CURL_FORMADD_MEMORY;
@@ -749,8 +750,7 @@ curl_formadd_ccsid(struct curl_httppost * * httppost,
 
     if (nargs >= lformlen) {
       lformlen += ALLOC_GRANULE;
-      tforms = (struct curl_forms *) realloc((char *) lforms,
-                                             lformlen * sizeof *lforms);
+      tforms = realloc(lforms, lformlen * sizeof *lforms);
 
       if (!tforms) {
         result = CURL_FORMADD_MEMORY;
@@ -1030,7 +1030,7 @@ curl_easy_setopt_ccsid(CURL * curl, CURLoption tag, ...)
   if (testwarn) {
     testwarn = 0;
 
-    if ((int) STRING_LAST != (int) STRING_SSH_HOST_PUBLIC_KEY_MD5 + 1)
+    if ((int) STRING_LAST != (int) STRING_PROXYPASSWORD + 1)
       curl_mfprintf(stderr,
        "*** WARNING: curl_easy_setopt_ccsid() should be reworked ***\n");
     }
@@ -1073,6 +1073,12 @@ curl_easy_setopt_ccsid(CURL * curl, CURLoption tag, ...)
   case CURLOPT_USERAGENT:
   case CURLOPT_USERPWD:
   case CURLOPT_SSH_HOST_PUBLIC_KEY_MD5:
+  case CURLOPT_CRLFILE:
+  case CURLOPT_ISSUERCERT:
+  case CURLOPT_USERNAME:
+  case CURLOPT_PASSWORD:
+  case CURLOPT_PROXYUSERNAME:
+  case CURLOPT_PROXYPASSWORD:
     s = va_arg(arg, char *);
     ccsid = va_arg(arg, unsigned int);
 
